#define VERSION				"0.996"
#define VERSION_C			0,996
#define DRIVERCONNECT                   104
#define CONFIGDSN                       105
#define IDC_DSNAME                      400
#define IDC_DSNAMETEXT                  401
#define IDC_DBNAME                      402
#define IDC_DBNAMETEXT                  403
#define IDC_DESC                        404
#define IDC_TONAME                      405
#define IDC_TONAMETEXT                  406
#define IDC_BROWSE			407
#define IDC_STEPAPI			408
#define IDC_NOWCHAR			409
#define IDC_SYNCP			410
#define IDC_SYNCPTEXT			411
#define IDC_NOTXN			412
#define IDC_LONGNAM			413
#define IDC_NOCREAT			414
#define IDC_SHORTNAM			415
#define IDC_LOADEXT			416
#define IDC_LOADEXTTEXT			417
#define IDC_FKSUPPORT			418
#define IDC_OEMCP			419
#define IDC_BIGINT			420
#define IDC_JDCONV			421
#define IDS_MSGTITLE                    500
#define IDS_BADDSN                      501
#define IDS_EXTTITLE			502
#define IDS_EXTERR			503
#define IDS_DRVTITLE			504
#define IDS_DLLERR			505 
#define IDC_STATIC                      -1
